RunnerType

Enum RunnerType 

pub enum RunnerType {
Show 15 variants Npm, Bun, Yarn, Pnpm, Make, Cargo, Flutter, Dart, Turbo, Poetry, Pdm, Just, Deno, Maven, DotNet,
}
The type of task runner detected

Variants



Npm



Bun



Yarn



Pnpm



Make



Cargo



Flutter



Dart



Turbo



Poetry



Pdm



Just



Deno



Maven



DotNet

Implementations

Source

impl RunnerType

pub fn display_name(&self) -> &'static str

Returns a human-readable display name for the runner type

pub fn icon(&self) -> &'static str

Get an icon/emoji for the runner type

pub fn color_code(&self) -> u8

Get a suggested terminal color for this runner type