pub fn scan_with_options(
root: impl AsRef<Path>,
options: ScanOptions,
) -> ScanResult<Vec<TaskRunner>>Expand description
Scan a directory tree for task runners with custom options. Uses scan_streaming internally and collects results.
pub fn scan_with_options(
root: impl AsRef<Path>,
options: ScanOptions,
) -> ScanResult<Vec<TaskRunner>>Scan a directory tree for task runners with custom options. Uses scan_streaming internally and collects results.